Learn R Programming

DCC (version 1.2.1)

dcc_dictionary: Canonical variable dictionary

Description

Returns the declared source name, canonical name, type, role, and any adapter metadata retained for each imported variable.

Usage

dcc_dictionary(x)

Value

A copy of the canonical variable dictionary.

Arguments

x

A dcc_data object.