powered by
Returns the declared source name, canonical name, type, role, and any adapter metadata retained for each imported variable.
dcc_dictionary(x)
A copy of the canonical variable dictionary.
A dcc_data object.
dcc_data